@@ -415,6 +415,12 @@ reference to the object.)
 		pre_reqs => ['pre_req1', 'pre_req2', ...],
 	);
 
+	# A scalar value, either provided alone or in a list, can be
+	# any of:
+	#    - an existing stage object
+	#    - a string - the exact value of some existing stage's name
+	#    - a regexp - all of the stages whose name matches the regexp
+
 The add_deps method marks the pre_req (or all of the pre_reqs)
 as being pre-requisites to the dep (or all of the deps).  When the
 group is executed, stages may be run in parallel, but a dependent
@@ -432,7 +438,7 @@ So, you could write:
 
 instead of:
 
-    $group->add_deps( pre_req=>'stage1', deps=>[qw(stage2 stage3)] );
+    $group->add_deps( pre_req=>'stage1', deps=>qr(^stage[23]$) );
     $group->add_deps( pre_req=>'stage2', dep=>'stage3' );
 
 or:
@@ -462,7 +468,15 @@ stages that were not part of the loop before this is noticed and
 the run aborted.
 
 Each stage argument passed can be either a reference to the stage
-object or the name of the stage.
+object or the name of the stage, or a regexp that select all of the
+stages whose name matches the regexp.  (If no stage name matches a
+regexp, then no stages are selected.  This allows using a regexp to
+match against an optional stage without having to check whether that
+optional stage was actually used in this run.  The downside is that
+a mistyped regexp will give no complaint when it matches nothing,
+but it is certainly not possibly to give a complaint if a mistyped
+regexp matches more stages than the user intended so checking the
+regexp carefully is necessary in any case.)
 
 =cut
 
