@@ -69,7 +69,7 @@ role {
 						$_next_to = 1;
 					}
 					else {
-						$self->info(
+						$self->warn(
 							"Reaper: kid: $kid, run: UNKNOWN, status: $stat"
 						);
 					}
