@@ -635,22 +635,32 @@ to code that checks the result.
 
 The code will be called with the arguments:
 
-    $coderef->( $stats, $stdout, $stderr )
+    $coderef->( $stats, $stdout, $stderr, $state )
         $stats  is a hashref containing the accounting info and status of the job
         $stdout is the pathname of the stdout file
         $stderr is the pathname of the srderr file
+        $state  is the state determined by HPCI
+                   (only pass/fail - retry has not been decided yet)
 
 The code can use these (and knowledge provided by the user about the stage
 operation) to test whether the stage succeeded.
 
-The return value from the code should be a string, one of:
+To select a specific state, the return value from the code should be a string, one of:
 
     pass
     fail
     retry
 
-to classify the result.  If the value is set to 'fail', other
-mechanisms may still apply to change that to 'retry'.
+If your function does not wish to select a state, it can return undef, and the
+same state that would be been chosen without the call to this function will be
+used unchanged.
+
+If the value returned is 'fail', other standard HPCI mechanisms may still apply
+that might change the choice to 'retry'.
+
+If the value returned is 'retry', it will either retry the stage or be
+changed to fail state, depending upon whether the limit for the choose_retries
+attribute has been reached.
 
 This code attribute could be used for:
 
@@ -658,6 +668,20 @@ This code attribute could be used for:
 
 - running a program that can give a zero status but not actually succeed (but perhaps a retry will succeed)
 
+An example might look like:
+
+    $group->stage(
+        ....
+        verify_completion_status => sub {
+            my( $stats, $stdout, $stderr, $state ) = @_;
+            # retry if output file is zero length
+            return 'retry' if $state eq 'pass' && ! -s $my_output_file;
+            # otherwise, normal processing
+            return;
+            },
+        ...
+        );
+
 =cut
 
 has 'verify_completion_state' => (
@@ -687,10 +711,12 @@ after '_analyse_completion_state' => sub {
         }
     }
     if ($self->_has_verify_completion_state) {
-        my $stats  = $run->stats;
-        my $stdout = $run->_stdout;
-        my $stderr = $run->_stderr;
-        my $code   = $self->verify_completion_state->( $stats, $stdout, $stderr );
+        my $code   = $self->verify_completion_state->(
+			$run->stats,
+			$run->_stdout,
+			$run->_stderr,
+			$self->state
+		);
         if ($code eq 'retry') {
             $code = 'fail';
             $run->_analysis_chose_retry(1);
@@ -708,7 +734,10 @@ failure.
 This pair of attributes specifies two aspects of making such a choice.
 
 First, the should_choose_retry attribute can be given a code reference to code
-that returns true if a retry should be made.  The sub is called with two arguments:
+that returns true if a retry should be made.  This code is only called if the
+stage run has failed.
+
+The sub is called with two arguments:
 the status hash containing the known status results from the most recent try to
 run the stage, and a string with the name of the stderr output file.  This code
 returns a true value to indicate that a retry should be attempted.  If this
@@ -716,7 +745,8 @@ attribute is not explicitly provided, it defaults to code that always returns 0
 to not cause a retry attempt.
 
 Second, the choose_retries attribute specifies number of times that the stage
-should be retried at the request of the should_choose_retry code.
+should be retried at the request of the should_choose_retry code (or at the
+request of the verify_completion_status code).
 The default is 1.
 
 =cut
